==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/nl.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'nl', {
	acccessKey: 'Toegangstoets',
	advanced: 'Geavanceerd',
	advisoryContentType: 'Aanbevolen content-type',
	advisoryTitle: 'Adviserende titel',
	anchor: {
		toolbar: 'Interne link',
		menu: 'Eigenschappen interne link',
		title: 'Eigenschappen interne link',
		name: 'Naam interne link',
		errorName: 'Geef de naam van de interne link op',
		remove: 'Interne link verwijderen'
	},
	anchorId: 'Op kenmerk interne link',
	anchorName: 'Op naam interne link',
	charset: 'Karakterset van gelinkte bron',
	cssClasses: 'Stylesheet-klassen',
	emailAddress: 'E-mailadres',
	emailBody: 'Inhoud bericht',
	emailSubject: 'Onderwerp bericht',
	id: 'Id',
	info: 'Linkomschrijving',
	langCode: 'Taalcode',
	langDir: 'Schrijfrichting',
	langDirLTR: 'Links naar rechts (LTR)',
	langDirRTL: 'Rechts naar links (RTL)',
	menu: 'Link wijzigen',
	name: 'Naam',
	noAnchors: '(Geen interne links in document gevonden)',
	noEmail: 'Geef een e-mailadres',
	noUrl: 'Geef de link van de URL',
	other: '<ander>',
	popupDependent: 'Afhankelijk (Netscape)',
	popupFeatures: 'Instellingen popupvenster',
	popupFullScreen: 'Volledig scherm (IE)',
	popupLeft: 'Positie links',
	popupLocationBar: 'Locatiemenu',
	popupMenuBar: 'Menubalk',
	popupResizable: 'Herschaalbaar',
	popupScrollBars: 'Schuifbalken',
	popupStatusBar: 'Statusbalk',
	popupToolbar: 'Werkbalk',
	popupTop: 'Positie boven',
	rel: 'Relatie',
	selectAnchor: 'Kies een interne link',
	styles: 'Stijl',
	tabIndex: 'Tabvolgorde',
	target: 'Doelvenster',
	targetFrame: '<frame>',
	targetFrameName: 'Naam doelframe',
	targetPopup: '<popupvenster>',
	targetPopupName: 'Naam popupvenster',
	title: 'Link',
	toAnchor: 'Interne link in pagina',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toolbar: 'Link invoegen/wijzigen',
	type: 'Linktype',
	unlink: 'Link verwijderen',
	upload: 'Upload'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/link/lang/nl.js <==
﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'nl', {
	acccessKey: 'Toegangstoets',
	advanced: 'Geavanceerd',
	advisoryContentType: 'Aanbevolen content-type',
	advisoryTitle: 'Adviserende titel',
	anchor: {
		toolbar: 'Interne link',
		menu: 'Eigenschappen interne link',
		title: 'Eigenschappen interne link',
		name: 'Naam interne link',
		errorName: 'Geef de naam van de interne link op',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Interne link verwijderen'
	},
	anchorId: 'Op kenmerk interne link',
	anchorName: 'Op naam interne link',
	charset: 'Karakterset van gelinkte bron',
	cssClasses: 'Stylesheet-klassen',
	download: 'Download forceren',
	displayText: 'Weergavetekst',
	emailAddress: 'E-mailadres',
	emailBody: 'Inhoud bericht',
	emailSubject: 'Onderwerp bericht',
	id: 'Id',
	info: 'Linkomschrijving',
	langCode: 'Taalcode',
	langDir: 'Schrijfrichting',
	langDirLTR: 'Links naar rechts (LTR)',
	langDirRTL: 'Rechts naar links (RTL)',
	menu: 'Link wijzigen',
	name: 'Naam',
	noAnchors: '(Geen interne links in document gevonden)',
	noEmail: 'Geef een e-mailadres',
	noUrl: 'Geef de link van de URL',
	noTel: 'Geef een telefoonnummer',
	other: '<ander>',
	phoneNumber: 'Telefoonnummer',
	popupDependent: 'Afhankelijk (Netscape)',
	popupFeatures: 'Instellingen popupvenster',
	popupFullScreen: 'Volledig scherm (IE)',
	popupLeft: 'Positie links',
	popupLocationBar: 'Locatiemenu',
	popupMenuBar: 'Menubalk',
	popupResizable: 'Herschaalbaar',
	popupScrollBars: 'Schuifbalken',
	popupStatusBar: 'Statusbalk',
	popupToolbar: 'Werkbalk',
	popupTop: 'Positie boven',
	rel: 'Relatie',
	selectAnchor: 'Kies een interne link',
	styles: 'Stijl',
	tabIndex: 'Tabvolgorde',
	target: 'Doelvenster',
	targetFrame: '<frame>',
	targetFrameName: 'Naam doelframe',
	targetPopup: '<popupvenster>',
	targetPopupName: 'Naam popupvenster',
	title: 'Link',
	toAnchor: 'Interne link in pagina',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toPhone: 'Telefoon',
	toolbar: 'Link invoegen/wijzigen',
	type: 'Linktype',
	unlink: 'Link verwijderen',
	upload: 'Upload'
} );
